@@ -167,6 +167,33 @@ QPoint Picmi::undo() {
     return coord;
 }
 
+QPoint Picmi::hint()
+{
+    QVector<QPoint> empty_cells;
+    for (int x = 0; x != width(); ++x) {
+        for (int y = 0; y != height(); ++y) {
+            if (stateAt(x, y) == Board::Nothing) {
+                empty_cells.push_back(QPoint(x, y));
+            }
+        }
+    }
+
+    if (empty_cells.size() == 0) {
+        return QPoint(0, 0);
+    }
+
+    const int idx = rand() % empty_cells.size();
+    const QPoint cell(empty_cells.at(idx));
+    Board::State state = m_map->get(cell.x(), cell.y());
+    if (state == Board::Nothing) {
+        state = Board::Cross;
+    }
+
+    setState(cell.x(), cell.y(), state);
+    m_timer.addPenaltyTime();
+    return cell;
+}
+
 KScoreDialog::FieldInfo Picmi::endGame() {
     m_timer.stop();
 
